@@ -6,7 +6,4 @@ if __name__ == "__main__":
     im = ImageGrab.grab()
 
     # save image file
-    im.save("screenshot.png")
-
-    # show image in a window
-    im.show()
+    im.save("fullscreen.png")
