@@ -1,11 +1,11 @@
 import logging
-import sys
 
 from PIL import Image
 
-PY2 = sys.version_info[0] == 2
+from pyscreenshot.plugins.backend import CBackend
+from pyscreenshot.util import py2
 
-if PY2:
+if py2():
     import StringIO
 
     BytesIO = StringIO.StringIO
@@ -19,33 +19,30 @@ log = logging.getLogger(__name__)
 
 # based on qt4 backend
 
+app = None
 
-class Qt5GrabWindow(object):
+
+class Qt5GrabWindow(CBackend):
     name = "pyqt5"
-    childprocess = False
 
-    app = None
+    # qt backends have conflict with each other in the same process.
 
     def __init__(self):
-        import PyQt5
+        pass
 
-        self.PyQt5 = PyQt5
+    def grab_to_buffer(self, buff, file_type="png"):
         from PyQt5 import QtGui
         from PyQt5 import Qt
         from PyQt5 import QtWidgets
 
-        self.QtGui = QtGui
-        self.Qt = Qt
-        self.QtWidgets = QtWidgets
+        QApplication = QtWidgets.QApplication
+        QBuffer = Qt.QBuffer
+        QIODevice = Qt.QIODevice
+        QScreen = QtGui.QScreen
 
-    def grab_to_buffer(self, buff, file_type="png"):
-        QApplication = self.QtWidgets.QApplication
-        QBuffer = self.PyQt5.Qt.QBuffer
-        QIODevice = self.PyQt5.Qt.QIODevice
-        QScreen = self.PyQt5.QtGui.QScreen
-
-        if not self.__class__.app:
-            self.__class__.app = QApplication([])
+        global app
+        if not app:
+            app = QApplication([])
         qbuffer = QBuffer()
         qbuffer.open(QIODevice.ReadWrite)
         QScreen.grabWindow(
@@ -64,4 +61,6 @@ class Qt5GrabWindow(object):
         return im
 
     def backend_version(self):
-        return self.Qt.PYQT_VERSION_STR
+        from PyQt5 import Qt
+
+        return Qt.PYQT_VERSION_STR
